aboutsummaryrefslogtreecommitdiffstats
path: root/src/core/thread/CtxCheckThread.cpp
diff options
context:
space:
mode:
authorSaturneric <[email protected]>2022-05-09 14:40:54 +0000
committerSaturneric <[email protected]>2022-05-09 14:40:54 +0000
commit670733f7a90d337d546afab22ddedeedec6d3d67 (patch)
tree2c64c0667d2cac45040257802c40963f89737700 /src/core/thread/CtxCheckThread.cpp
parentdoc: add entry to developer document. (diff)
downloadGpgFrontend-670733f7a90d337d546afab22ddedeedec6d3d67.tar.gz
GpgFrontend-670733f7a90d337d546afab22ddedeedec6d3d67.zip
fix: fix crash poblem when doing operations
1. refactor GpgFunctionObject to solve shared library problem. 2. fix multi-threading issues in refreshing. 3. improve loading speed for key list 4. improve ui operation 5. do other fixing and improving operations
Diffstat (limited to 'src/core/thread/CtxCheckThread.cpp')
-rw-r--r--src/core/thread/CtxCheckThread.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/core/thread/CtxCheckThread.cpp b/src/core/thread/CtxCheckThread.cpp
index 77571dfd..edec8855 100644
--- a/src/core/thread/CtxCheckThread.cpp
+++ b/src/core/thread/CtxCheckThread.cpp
@@ -48,7 +48,7 @@ void GpgFrontend::CtxCheckThread::run() {
if (!GpgContext::GetInstance().good()) {
emit SignalGnupgNotInstall();
}
// Try fetching key
else
- GpgFrontend::GpgKeyGetter::GetInstance().FetchKey();
+ GpgFrontend::GpgKeyGetter::GetInstance().FlushKeyCache();
}
@@ -48,7 +48,7 @@ void GpgFrontend::CtxCheckThread::run() {
emit SignalGnupgNotInstall();
}
- // Try fetching key
+ // Try flushing key cache
else